Module cli

Module cli 

Represents a clap based CLI app module

struct, enums that use clap derive macro to produce CLI commands, argument and options with underlying functions to handle each scenario. enabled by default or by cli feature if default features i off.

Modules

build
generate
magic
output
schema
schema_check
solc
subgraph
validate

Enums

Meta

Functions

dispatch
main