Build a rain meta document from command line options.
Enforces length constraints on the input paths, magic numbers, content types,
content encodings and content languages.
Handles reading input files and writing to files/stdout according to the
build options.