pub fn json_schema(meta: KnownMeta) -> Option<RootSchema>Expand description
Single source of truth for which metas ls advertises and show can
produce. Matched exhaustively so a new KnownMeta cannot be silently
absent from both.
pub fn json_schema(meta: KnownMeta) -> Option<RootSchema>Single source of truth for which metas ls advertises and show can
produce. Matched exhaustively so a new KnownMeta cannot be silently
absent from both.