Module schema_check

Module schema_check 

Structs

SchemaCheck
Compare entity types in a subgraph schema against a consumer’s snapshot of the deployed introspection schema. Used in deploy CI to fail early when the consumer’s snapshot has drifted from what is about to be deployed.

Functions

schema_check