#[repr(u64)]pub enum KnownMagic {
Show 20 variants
RainMetaDocumentV1 = 18_377_652_714_897_045_620,
OpMetaV1 = 18_439_188_432_805_991_860,
DotrainV1 = 18_436_262_373_317_404_820,
RainlangV1 = 18_382_595_872_068_946_087,
SolidityAbiV2 = 18_439_425_400_648_969_438,
AuthoringMetaV1 = 18_440_520_426_328_744_501,
AuthoringMetaV2 = 18_398_046_991_237_009_555,
InterpreterCallerMetaV1 = 18_429_323_134_567_717_275,
ExpressionDeployerV2BytecodeV1 = 18_436_497_220_406_627_634,
RainlangSourceV1 = 18_380_052_776_113_893_362,
AddressList = 18_424_898_384_130_252_344,
DotrainSourceV1 = 18_420_108_340_039_479_449,
OrderBuilderStateV1 = 18_436_183_469_364_593_286,
RaindexSignedContextOracleV1 = 18_409_049_549_764_303_306,
WebDataV1 = 18_401_088_956_649_290_306,
OaSchema = 18_422_230_091_423_500_849,
OaHashList = 18_419_632_577_016_362_083,
OaStructure = 18_429_990_139_014_457_617,
OaTokenImage = 18_414_324_503_007_758_027,
OaTokenCredentialLinks = 18_427_666_357_608_587_785,
}Expand description
All known Rain magic numbers
Variants
RainMetaDocumentV1 = 18_377_652_714_897_045_620
Prefixes every rain meta document. This is the only place it appears: an item claiming it as its own magic is malformed, not a nested document, and does not decode.
OpMetaV1 = 18_439_188_432_805_991_860
Ops meta v1
DotrainV1 = 18_436_262_373_317_404_820
Dotrain meta v1
RainlangV1 = 18_382_595_872_068_946_087
Rainlang meta v1
SolidityAbiV2 = 18_439_425_400_648_969_438
Solidity ABI meta v2
AuthoringMetaV1 = 18_440_520_426_328_744_501
Authoring meta v1
AuthoringMetaV2 = 18_398_046_991_237_009_555
InterpreterCallerMetaV1 = 18_429_323_134_567_717_275
InterpreterCaller meta v1
ExpressionDeployerV2BytecodeV1 = 18_436_497_220_406_627_634
ExpressionDeployer deployed bytecode meta v1
RainlangSourceV1 = 18_380_052_776_113_893_362
Rainlang source code meta v1
AddressList = 18_424_898_384_130_252_344
DotrainSourceV1 = 18_420_108_340_039_479_449
Dotrain source code meta v1
OrderBuilderStateV1 = 18_436_183_469_364_593_286
Order builder state meta v1
RaindexSignedContextOracleV1 = 18_409_049_549_764_303_306
Signed context oracle endpoint v1 Payload is raw UTF-8 bytes containing the oracle endpoint URL. Used in order metadata to tell takers where to GET signed context data.
WebDataV1 = 18_401_088_956_649_290_306
Web data v1
OaSchema = 18_422_230_091_423_500_849
OffchainAsset schema reference for offchain asset data
OaHashList = 18_419_632_577_016_362_083
OffchainAsset IPFS hash list for offchain assets
OaStructure = 18_429_990_139_014_457_617
OffchainAsset structured data (e.g. receipt information)
OaTokenImage = 18_414_324_503_007_758_027
OffchainAsset token image metadata
OaTokenCredentialLinks = 18_427_666_357_608_587_785
OffchainAsset token credential links
Implementations
Sourceimpl KnownMagic
impl KnownMagic
pub fn to_prefix_bytes(&self) -> [u8; 8]