Module schema_check
rain_
metadata
0.1.2
Module schema_
check
Module Items
Structs
Functions
In rain_
metadata::
cli
rain_metadata
::
cli
Module
schema_
check
Structs

Schema
Check
Compare entity types in a subgraph schema against a consumer’s snapshot of the deployed introspection schema. Used in deploy CI to fail early when the consumer’s snapshot has drifted from what is about to be deployed.
Functions

schema_
check